@@ -51,7 +51,7 @@ def text_decorate(string: str, decoration: str="BOLD"):
     endd = ansi["END"]
     return f"{text_dec}{string}{endd}"
 
-def get_funcs(all_funcs=globals().items(), ignore_char: str="_"):
+def get_funcs(all_funcs, ignore_char: str="_"):
     funcs = []
     for key, value in all_funcs:
         if callable(value) and not re.match(f"^{ignore_char}.*", key):
